@@ -15,7 +15,6 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class DummyEffect:
-
     config = vol.Schema({})
     _active = True
     is_active = _active
@@ -92,6 +91,8 @@ def _gaussian_kernel1d(sigma, order, array_len):
     # Choose a radius for the filter kernel large enough to include all significant elements. Using
     # a radius of 4 standard deviations (rounded to int) will only truncate tail values that are of
     # the order of 1e-5 or smaller. For very small sigma values, just use a minimal radius.
+    # trapping very small values of sigma to arbitarily 0.00001 to preven div zero crash
+    sigma = max(0.00001, sigma)
     radius = max(1, int(round(4.0 * sigma)))
     radius = min(int((array_len - 1) / 2), radius)
     radius = max(radius, 1)
@@ -274,7 +275,6 @@ class Effect(BaseRegistry):
         prior_config = self._config
 
         if self._config != {}:
-
             self._config = {**prior_config, **config}
         else:
             self._config = validated_config
