@@ -1,4 +1,5 @@
 import logging
+import sys
 import threading
 import time
 import timeit
@@ -34,7 +35,6 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class Virtual:
-
     CONFIG_SCHEMA = vol.Schema(
         {
             vol.Required(
@@ -123,6 +123,13 @@ class Virtual:
     _active_effect = None
     _transition_effect = None
 
+    if (
+        sys.version_info[0] == 3 and sys.version_info[1] >= 11
+    ) or sys.version_info[0] >= 4:
+        _min_time = time.get_clock_info("perf_counter").resolution
+    else:
+        _min_time = time.get_clock_info("monotonic").resolution
+
     def __init__(self, ledfx, config):
         self._ledfx = ledfx
         self._config = config
@@ -349,6 +356,17 @@ class Virtual:
 
             self._active = False
 
+    def force_frame(self, color):
+        """
+        Force all pixels in device to color
+        Use for pre-clearing in calibration scenarios
+        """
+        self.assembled_frame = np.full((self.pixel_count, 3), color)
+        self.flush(self.assembled_frame)
+        self._ledfx.events.fire_event(
+            VirtualUpdateEvent(self.id, self.assembled_frame)
+        )
+
     @property
     def active_effect(self):
         return self._active_effect
@@ -379,13 +397,20 @@ class Virtual:
                         VirtualUpdateEvent(self.id, self.assembled_frame)
                     )
 
-            time.sleep(fps_to_sleep_interval(self.refresh_rate))
+            # adjust for the frame assemble time, min allowed sleep 1 ms
+            # this will be more frame accurate on high res sleep systems
+            run_time = timeit.default_timer() - start_time
+            sleep_time = max(
+                0.001, fps_to_sleep_interval(self.refresh_rate) - run_time
+            )
+            time.sleep(sleep_time)
+
+            # use an aggressive check for did we sleep against expected min clk
+            # for all high res scenarios this will be passive
+            # for unexpected high res sleep on windows scenarios it will adapt
             pass_time = timeit.default_timer() - start_time
-            min_time = time.get_clock_info("monotonic").resolution
-            # use an aggressive check for did we sleep against implied min
-            # for all otherwise working behaviours this will be passive
-            if pass_time < (min_time / 2):
-                time.sleep(min_time - pass_time)
+            if pass_time < (self._min_time / 2):
+                time.sleep(max(0.001, self._min_time - pass_time))
 
     def assemble_frame(self):
         """
@@ -439,6 +464,7 @@ class Virtual:
                 self.clear_transition_effect()
 
         np.multiply(frame, self._config["max_brightness"], frame)
+        np.multiply(frame, self._ledfx.config["global_brightness"], frame)
 
         return frame
 
